/**************************************************************************\
 * Copyright (c) Kongsberg Oil & Gas Technologies AS
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 
 * Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\**************************************************************************/

/*  $Id$  */
/*    */

#ifndef SOQT_ROCOCOMATERIALS_IV_H
#define SOQT_ROCOCOMATERIALS_IV_H

/* ********************************************************************** */

#include <materials/rococo/rococo_0.h>
#include <materials/rococo/rococo_1.h>
#include <materials/rococo/rococo_2.h>
#include <materials/rococo/rococo_3.h>
#include <materials/rococo/rococo_4.h>
#include <materials/rococo/rococo_5.h>
#include <materials/rococo/rococo_6.h>
#include <materials/rococo/rococo_7.h>
#include <materials/rococo/rococo_8.h>
#include <materials/rococo/rococo_9.h>
#include <materials/rococo/rococo_10.h>
#include <materials/rococo/rococo_11.h>
#include <materials/rococo/rococo_12.h>
#include <materials/rococo/rococo_13.h>
#include <materials/rococo/rococo_14.h>
#include <materials/rococo/rococo_15.h>
#include <materials/rococo/rococo_16.h>
#include <materials/rococo/rococo_17.h>
#include <materials/rococo/rococo_18.h>
#include <materials/rococo/rococo_19.h>
#include <materials/rococo/rococo_20.h>
#include <materials/rococo/rococo_21.h>
#include <materials/rococo/rococo_22.h>
#include <materials/rococo/rococo_23.h>
#include <materials/rococo/rococo_24.h>
#include <materials/rococo/rococo_25.h>
#include <materials/rococo/rococo_26.h>
#include <materials/rococo/rococo_27.h>
#include <materials/rococo/rococo_28.h>
#include <materials/rococo/rococo_29.h>
#include <materials/rococo/rococo_30.h>
#include <materials/rococo/rococo_31.h>
#include <materials/rococo/rococo_32.h>
#include <materials/rococo/rococo_33.h>
#include <materials/rococo/rococo_34.h>

/* ********************************************************************** */

#endif /* SOQT_ROCOCOMATERIALS_IV_H */
